/* vnc-display.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from vnc-display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <gtk-vnc.h>
#include <libxml/uri.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;

#define BOXES_TYPE_VNC_DISPLAY (boxes_vnc_display_get_type ())
#define BOXES_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay))
#define BOXES_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))
#define BOXES_IS_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_IS_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_VNC_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))

typedef struct _BoxesVncDisplay BoxesVncDisplay;
typedef struct _BoxesVncDisplayClass BoxesVncDisplayClass;
typedef struct _BoxesVncDisplayPrivate BoxesVncDisplayPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef gint (*BoxesDisplayOpenFDFunc) (void* user_data);
struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	gboolean connected;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	void (*send_keys) (BoxesDisplay* self, guint* keyvals, int keyvals_length1);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesVncDisplay {
	BoxesDisplay parent_instance;
	BoxesVncDisplayPrivate * priv;
};

struct _BoxesVncDisplayClass {
	BoxesDisplayClass parent_class;
};

struct _BoxesVncDisplayPrivate {
	VncDisplay* display;
	gchar* host;
	gint port;
	GtkWindow* window;
	BoxesBoxConfigSavedProperty* saved_properties;
	gint saved_properties_length1;
	gint _saved_properties_size_;
};


static gpointer boxes_vnc_display_parent_class = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
GType boxes_vnc_display_get_type (void) G_GNUC_CONST;
#define BOXES_VNC_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayPrivate))
enum  {
	BOXES_VNC_DISPLAY_DUMMY_PROPERTY,
	BOXES_VNC_DISPLAY_PROTOCOL,
	BOXES_VNC_DISPLAY_URI
};
static void _vala_BoxesBoxConfigSavedProperty_array_free (BoxesBoxConfigSavedProperty* array, gint array_length);
BoxesVncDisplay* boxes_vnc_display_new (BoxesBoxConfig* config, const gchar* host, gint port);
BoxesVncDisplay* boxes_vnc_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port);
BoxesDisplay* boxes_display_construct (GType object_type);
void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value);
BoxesVncDisplay* boxes_vnc_display_new_with_uri (BoxesBoxConfig* config, const gchar* _uri, GError** error);
BoxesVncDisplay* boxes_vnc_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* _uri, GError** error);
static GtkWidget* boxes_vnc_display_real_get_display (BoxesDisplay* base, gint n);
static void boxes_vnc_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable);
static GdkPixbuf* boxes_vnc_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error);
static void boxes_vnc_display_real_connect_it (BoxesDisplay* base, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error);
const gchar* boxes_display_get_username (BoxesDisplay* self);
const gchar* boxes_display_get_password (BoxesDisplay* self);
static void boxes_vnc_display_real_disconnect_it (BoxesDisplay* base);
static GList* boxes_vnc_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_vnc_display_real_send_keys (BoxesDisplay* base, guint* keyvals, int keyvals_length1);
static GObject * boxes_vnc_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
static void _boxes_vnc_display___lambda78_ (BoxesVncDisplay* self);
void boxes_display_access_start (BoxesDisplay* self);
static void __boxes_vnc_display___lambda78__vnc_display_vnc_initialized (VncDisplay* _sender, gpointer self);
static void _boxes_vnc_display___lambda79_ (BoxesVncDisplay* self);
void boxes_display_access_finish (BoxesDisplay* self);
static void __boxes_vnc_display___lambda79__vnc_display_vnc_disconnected (VncDisplay* _sender, gpointer self);
static void _boxes_vnc_display___lambda80_ (BoxesVncDisplay* self);
static void __boxes_vnc_display___lambda80__vnc_display_vnc_auth_failure (VncDisplay* _sender, const gchar* object, gpointer self);
static void _boxes_vnc_display___lambda81_ (BoxesVncDisplay* self);
static void __boxes_vnc_display___lambda81__vnc_display_vnc_auth_unsupported (VncDisplay* _sender, guint object, gpointer self);
static void _boxes_vnc_display___lambda82_ (BoxesVncDisplay* self, GValueArray* creds);
void boxes_display_set_need_username (BoxesDisplay* self, gboolean value);
const gchar* vnc_display_credential_to_string (VncDisplayCredential self);
static void __boxes_vnc_display___lambda82__vnc_display_vnc_auth_credential (VncDisplay* _sender, GValueArray* credList, gpointer self);
static void boxes_vnc_display_finalize (GObject* obj);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void _vala_boxes_vnc_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static void _vala_BoxesBoxConfigSavedProperty_array_free (BoxesBoxConfigSavedProperty* array, gint array_length) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (array != NULL) {
#line 178 "vnc-display.c"
		int i;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			boxes_box_config_saved_property_destroy (&array[i]);
#line 184 "vnc-display.c"
		}
	}
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_free (array);
#line 189 "vnc-display.c"
}


BoxesVncDisplay* boxes_vnc_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port) {
	BoxesVncDisplay * self = NULL;
	BoxesBoxConfig* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	BoxesBoxConfig* _tmp4_ = NULL;
	VncDisplay* _tmp5_ = NULL;
	BoxesBoxConfigSavedProperty* _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_return_val_if_fail (host != NULL, NULL);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) boxes_display_construct (object_type);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = config;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp0_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = host;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_free0 (self->priv->host);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->host = _tmp2_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_ = port;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->port = _tmp3_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp4_ = config;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp5_ = self->priv->display;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp6_ = self->priv->saved_properties;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp6__length1 = self->priv->saved_properties_length1;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_box_config_save_properties (_tmp4_, (GObject*) _tmp5_, _tmp6_, _tmp6__length1);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return self;
#line 237 "vnc-display.c"
}


BoxesVncDisplay* boxes_vnc_display_new (BoxesBoxConfig* config, const gchar* host, gint port) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return boxes_vnc_display_construct (BOXES_TYPE_VNC_DISPLAY, config, host, port);
#line 244 "vnc-display.c"
}


BoxesVncDisplay* boxes_vnc_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* _uri, GError** error) {
	BoxesVncDisplay * self = NULL;
	BoxesBoxConfig* _tmp0_ = NULL;
	xmlURI* uri = NULL;
	const gchar* _tmp1_ = NULL;
	xmlURI* _tmp2_ = NULL;
	xmlURI* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	xmlURI* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	xmlURI* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	xmlURI* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	BoxesBoxConfig* _tmp17_ = NULL;
	VncDisplay* _tmp18_ = NULL;
	BoxesBoxConfigSavedProperty* _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	GError * _inner_error_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_return_val_if_fail (_uri != NULL, NULL);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) boxes_display_construct (object_type);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = config;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp0_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = _uri;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_ = xmlParseURI (_tmp1_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	uri = _tmp2_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_ = uri;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp4_ = _tmp3_->scheme;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (g_strcmp0 (_tmp4_, "vnc") != 0) {
#line 291 "vnc-display.c"
		GError* _tmp5_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "the URL is not vnc://");
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_inner_error_ = _tmp5_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_propagate_error (error, _inner_error_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_xmlFreeURI0 (uri);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_g_object_unref0 (self);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			return NULL;
#line 307 "vnc-display.c"
		} else {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_xmlFreeURI0 (uri);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_clear_error (&_inner_error_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			return NULL;
#line 317 "vnc-display.c"
		}
	}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp6_ = uri;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp7_ = _tmp6_->server;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (_tmp7_ == NULL) {
#line 326 "vnc-display.c"
		GError* _tmp8_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp8_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "the URL is missing a server");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_inner_error_ = _tmp8_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_propagate_error (error, _inner_error_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_xmlFreeURI0 (uri);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_g_object_unref0 (self);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			return NULL;
#line 342 "vnc-display.c"
		} else {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_xmlFreeURI0 (uri);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_clear_error (&_inner_error_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			return NULL;
#line 352 "vnc-display.c"
		}
	}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp9_ = uri;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp10_ = _tmp9_->server;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_free0 (self->priv->host);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->host = _tmp11_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp13_ = uri;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp14_ = _tmp13_->port;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (_tmp14_ <= 0) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp12_ = 5900;
#line 373 "vnc-display.c"
	} else {
		xmlURI* _tmp15_ = NULL;
		gint _tmp16_ = 0;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp15_ = uri;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp16_ = _tmp15_->port;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp12_ = _tmp16_;
#line 383 "vnc-display.c"
	}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->port = _tmp12_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp17_ = config;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp18_ = self->priv->display;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp19_ = self->priv->saved_properties;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp19__length1 = self->priv->saved_properties_length1;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_box_config_save_properties (_tmp17_, (GObject*) _tmp18_, _tmp19_, _tmp19__length1);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_xmlFreeURI0 (uri);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return self;
#line 401 "vnc-display.c"
}


BoxesVncDisplay* boxes_vnc_display_new_with_uri (BoxesBoxConfig* config, const gchar* _uri, GError** error) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return boxes_vnc_display_construct_with_uri (BOXES_TYPE_VNC_DISPLAY, config, _uri, error);
#line 408 "vnc-display.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return self ? g_object_ref (self) : NULL;
#line 415 "vnc-display.c"
}


static GtkWidget* boxes_vnc_display_real_get_display (BoxesDisplay* base, gint n) {
	BoxesVncDisplay * self;
	GtkWidget* result = NULL;
	GtkWindow* _tmp0_ = NULL;
	VncDisplay* _tmp1_ = NULL;
	VncDisplay* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = self->priv->window;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = self->priv->display;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	gtk_container_remove ((GtkContainer*) _tmp0_, (GtkWidget*) _tmp1_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_ = self->priv->display;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_ = _g_object_ref0 ((GtkWidget*) _tmp2_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	result = _tmp3_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return result;
#line 442 "vnc-display.c"
}


static void boxes_vnc_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable) {
	BoxesVncDisplay * self;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 450 "vnc-display.c"
}


static GdkPixbuf* boxes_vnc_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error) {
	BoxesVncDisplay * self;
	GdkPixbuf* result = NULL;
	VncDisplay* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = self->priv->display;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = vnc_display_get_pixbuf (_tmp0_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	result = _tmp1_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return result;
#line 469 "vnc-display.c"
}


static void boxes_vnc_display_real_connect_it (BoxesDisplay* base, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error) {
	BoxesVncDisplay * self;
	gboolean _tmp0_ = FALSE;
	VncDisplay* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	VncDisplay* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	VncDisplay* _tmp7_ = NULL;
	BoxesDisplayOpenFDFunc _tmp8_ = NULL;
	void* _tmp8__target = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = ((BoxesDisplay*) self)->connected;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (_tmp0_) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		(open_fd_target_destroy_notify == NULL) ? NULL : (open_fd_target_destroy_notify (open_fd_target), NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		open_fd = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		open_fd_target = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		open_fd_target_destroy_notify = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		return;
#line 501 "vnc-display.c"
	}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplay*) self)->connected = TRUE;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = self->priv->display;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_ = boxes_display_get_username ((BoxesDisplay*) self);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_ = _tmp2_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_credential (_tmp1_, (gint) VNC_DISPLAY_CREDENTIAL_USERNAME, _tmp3_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp4_ = self->priv->display;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp5_ = boxes_display_get_password ((BoxesDisplay*) self);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp6_ = _tmp5_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_credential (_tmp4_, (gint) VNC_DISPLAY_CREDENTIAL_PASSWORD, _tmp6_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp7_ = self->priv->display;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_credential (_tmp7_, (gint) VNC_DISPLAY_CREDENTIAL_CLIENTNAME, "boxes");
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp8_ = open_fd;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp8__target = open_fd_target;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (_tmp8_ != NULL) {
#line 531 "vnc-display.c"
		gint fd = 0;
		BoxesDisplayOpenFDFunc _tmp9_ = NULL;
		void* _tmp9__target = NULL;
		gint _tmp10_ = 0;
		VncDisplay* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		const gchar* _tmp13_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp9_ = open_fd;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp9__target = open_fd_target;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp10_ = _tmp9_ (_tmp9__target);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		fd = _tmp10_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp11_ = self->priv->display;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp12_ = fd;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp13_ = self->priv->host;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		vnc_display_open_fd_with_hostname (_tmp11_, _tmp12_, _tmp13_);
#line 555 "vnc-display.c"
	} else {
		VncDisplay* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp14_ = self->priv->display;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp15_ = self->priv->host;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp16_ = self->priv->port;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp17_ = g_strdup_printf ("%i", _tmp16_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp18_ = _tmp17_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		vnc_display_open_host (_tmp14_, _tmp15_, _tmp18_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_g_free0 (_tmp18_);
#line 576 "vnc-display.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	(open_fd_target_destroy_notify == NULL) ? NULL : (open_fd_target_destroy_notify (open_fd_target), NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	open_fd = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	open_fd_target = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	open_fd_target_destroy_notify = NULL;
#line 586 "vnc-display.c"
}


static void boxes_vnc_display_real_disconnect_it (BoxesDisplay* base) {
	BoxesVncDisplay * self;
	VncDisplay* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = self->priv->display;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = vnc_display_is_open (_tmp0_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	if (_tmp1_) {
#line 602 "vnc-display.c"
		VncDisplay* _tmp2_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		_tmp2_ = self->priv->display;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		vnc_display_close (_tmp2_);
#line 608 "vnc-display.c"
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 616 "vnc-display.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_list_free (self);
#line 625 "vnc-display.c"
}


static GList* boxes_vnc_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page) {
	BoxesVncDisplay * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	list = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = page;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	switch (_tmp0_) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 644 "vnc-display.c"
		{
			GtkSwitch* toggle = NULL;
			GtkSwitch* _tmp1_ = NULL;
			GtkSwitch* _tmp2_ = NULL;
			VncDisplay* _tmp3_ = NULL;
			GtkSwitch* _tmp4_ = NULL;
			const gchar* _tmp5_ = NULL;
			GtkSwitch* _tmp6_ = NULL;
			BoxesProperty* _tmp7_ = NULL;
			BoxesProperty* _tmp8_ = NULL;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp1_ = (GtkSwitch*) gtk_switch_new ();
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_object_ref_sink (_tmp1_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			toggle = _tmp1_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp2_ = toggle;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp2_, GTK_ALIGN_START);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp3_ = self->priv->display;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp4_ = toggle;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			g_object_bind_property_with_closures ((GObject*) _tmp3_, "read-only", (GObject*) _tmp4_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp5_ = _ ("Read-only");
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp6_ = toggle;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp7_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp5_, (GtkWidget*) _tmp6_, NULL);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_tmp8_ = _tmp7_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_g_object_unref0 (_tmp8_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			_g_object_unref0 (toggle);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			break;
#line 685 "vnc-display.c"
		}
		default:
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		break;
#line 690 "vnc-display.c"
	}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	result = list;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return result;
#line 696 "vnc-display.c"
}


static void boxes_vnc_display_real_send_keys (BoxesDisplay* base, guint* keyvals, int keyvals_length1) {
	BoxesVncDisplay * self;
	VncDisplay* _tmp0_ = NULL;
	guint* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = self->priv->display;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = keyvals;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1__length1 = keyvals_length1;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_send_keys (_tmp0_, _tmp1_, _tmp1__length1);
#line 715 "vnc-display.c"
}


static const gchar* boxes_vnc_display_real_get_protocol (BoxesDisplay* base) {
	const gchar* result;
	BoxesVncDisplay* self;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	result = "VNC";
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return result;
#line 728 "vnc-display.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 740 "vnc-display.c"
}


static gchar* boxes_vnc_display_real_get_uri (BoxesDisplay* base) {
	gchar* result;
	BoxesVncDisplay* self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = (BoxesVncDisplay*) base;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = self->priv->host;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp1_ = string_to_string (_tmp0_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_ = self->priv->port;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_ = g_strdup_printf ("%i", _tmp2_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp4_ = _tmp3_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp5_ = g_strconcat ("vnc://", _tmp1_, ":", _tmp4_, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp6_ = _tmp5_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_free0 (_tmp4_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	result = _tmp6_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return result;
#line 776 "vnc-display.c"
}


static void _boxes_vnc_display___lambda78_ (BoxesVncDisplay* self) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "show", 0);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_display_access_start ((BoxesDisplay*) self);
#line 785 "vnc-display.c"
}


static void __boxes_vnc_display___lambda78__vnc_display_vnc_initialized (VncDisplay* _sender, gpointer self) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_boxes_vnc_display___lambda78_ ((BoxesVncDisplay*) self);
#line 792 "vnc-display.c"
}


static void _boxes_vnc_display___lambda79_ (BoxesVncDisplay* self) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "hide", 0);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_display_access_finish ((BoxesDisplay*) self);
#line 801 "vnc-display.c"
}


static void __boxes_vnc_display___lambda79__vnc_display_vnc_disconnected (VncDisplay* _sender, gpointer self) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_boxes_vnc_display___lambda79_ ((BoxesVncDisplay*) self);
#line 808 "vnc-display.c"
}


static void _boxes_vnc_display___lambda80_ (BoxesVncDisplay* self) {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_debug ("vnc-display.vala:42: auth failure");
#line 815 "vnc-display.c"
}


static void __boxes_vnc_display___lambda80__vnc_display_vnc_auth_failure (VncDisplay* _sender, const gchar* object, gpointer self) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_boxes_vnc_display___lambda80_ ((BoxesVncDisplay*) self);
#line 822 "vnc-display.c"
}


static void _boxes_vnc_display___lambda81_ (BoxesVncDisplay* self) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_debug ("vnc-display.vala:45: auth unsupported");
#line 829 "vnc-display.c"
}


static void __boxes_vnc_display___lambda81__vnc_display_vnc_auth_unsupported (VncDisplay* _sender, guint object, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_boxes_vnc_display___lambda81_ ((BoxesVncDisplay*) self);
#line 836 "vnc-display.c"
}


static void _boxes_vnc_display___lambda82_ (BoxesVncDisplay* self, GValueArray* creds) {
	GValueArray* _tmp0_ = NULL;
	VncDisplay* _tmp7_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_return_if_fail (creds != NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = creds;
#line 847 "vnc-display.c"
	{
		GValueArray* cred_collection = NULL;
		guint cred_index = 0U;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		cred_collection = _tmp0_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		for (cred_index = 0; cred_index < cred_collection->n_values; cred_index = cred_index + 1) {
#line 855 "vnc-display.c"
			GValue cred = {0};
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
			cred = *g_value_array_get_nth (cred_collection, cred_index);
#line 859 "vnc-display.c"
			{
				VncDisplayCredential credential = 0;
				GValue _tmp1_ = {0};
				VncDisplayCredential _tmp2_ = 0;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
				_tmp1_ = cred;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
				credential = g_value_get_enum (&_tmp1_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
				_tmp2_ = credential;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
				switch (_tmp2_) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
					case VNC_DISPLAY_CREDENTIAL_USERNAME:
#line 874 "vnc-display.c"
					{
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						boxes_display_set_need_username ((BoxesDisplay*) self, TRUE);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						break;
#line 880 "vnc-display.c"
					}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
					case VNC_DISPLAY_CREDENTIAL_PASSWORD:
#line 884 "vnc-display.c"
					{
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						boxes_display_set_need_password ((BoxesDisplay*) self, TRUE);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						break;
#line 890 "vnc-display.c"
					}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
					case VNC_DISPLAY_CREDENTIAL_CLIENTNAME:
#line 894 "vnc-display.c"
					{
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						break;
#line 898 "vnc-display.c"
					}
					default:
					{
						VncDisplayCredential _tmp3_ = 0;
						GEnumValue* _tmp4_;
						gchar* _tmp5_ = NULL;
						gchar* _tmp6_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						_tmp3_ = credential;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						_tmp4_ = g_enum_get_value (g_type_class_ref (vnc_display_credential_get_type ()), _tmp3_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						_tmp5_ = g_strdup_printf ("Unsupported credential: %s", (_tmp4_ != NULL) ? _tmp4_->value_name : NULL);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						_tmp6_ = _tmp5_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						g_debug ("vnc-display.vala:65: %s", _tmp6_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						_g_free0 (_tmp6_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
						break;
#line 920 "vnc-display.c"
					}
				}
			}
		}
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp7_ = self->priv->display;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_close (_tmp7_);
#line 930 "vnc-display.c"
}


static void __boxes_vnc_display___lambda82__vnc_display_vnc_auth_credential (VncDisplay* _sender, GValueArray* credList, gpointer self) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_boxes_vnc_display___lambda82_ ((BoxesVncDisplay*) self, credList);
#line 937 "vnc-display.c"
}


static GObject * boxes_vnc_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesVncDisplay * self;
	gchar* _tmp0_ = NULL;
	GValue _tmp1_ = {0};
	BoxesBoxConfigSavedProperty _tmp2_ = {0};
	BoxesBoxConfigSavedProperty* _tmp3_ = NULL;
	VncDisplay* _tmp4_ = NULL;
	VncDisplay* _tmp5_ = NULL;
	VncDisplay* _tmp6_ = NULL;
	VncDisplay* _tmp7_ = NULL;
	VncDisplay* _tmp8_ = NULL;
	GtkWindow* _tmp9_ = NULL;
	GtkWindow* _tmp10_ = NULL;
	VncDisplay* _tmp11_ = NULL;
	VncDisplay* _tmp12_ = NULL;
	VncDisplay* _tmp13_ = NULL;
	VncDisplay* _tmp14_ = NULL;
	VncDisplay* _tmp15_ = NULL;
	VncDisplay* _tmp16_ = NULL;
	VncDisplay* _tmp17_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	parent_class = G_OBJECT_CLASS (boxes_vnc_display_parent_class);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp0_ = g_strdup ("read-only");
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_value_set_boolean (&_tmp1_, FALSE);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	memset (&_tmp2_, 0, sizeof (BoxesBoxConfigSavedProperty));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_free0 (_tmp2_.name);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_.name = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	G_IS_VALUE (&_tmp2_.default_value) ? (g_value_unset (&_tmp2_.default_value), NULL) : NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp2_.default_value = _tmp1_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_ = g_new0 (BoxesBoxConfigSavedProperty, 1);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp3_[0] = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->saved_properties = (_vala_BoxesBoxConfigSavedProperty_array_free (self->priv->saved_properties, self->priv->saved_properties_length1), NULL);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->saved_properties = _tmp3_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->saved_properties_length1 = 1;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->_saved_properties_size_ = self->priv->saved_properties_length1;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_display_set_need_password ((BoxesDisplay*) self, FALSE);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp4_ = (VncDisplay*) vnc_display_new ();
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_object_ref_sink (_tmp4_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_object_unref0 (self->priv->display);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->display = _tmp4_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp5_ = self->priv->display;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_keyboard_grab (_tmp5_, TRUE);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp6_ = self->priv->display;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_pointer_grab (_tmp6_, TRUE);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp7_ = self->priv->display;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_force_size (_tmp7_, FALSE);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp8_ = self->priv->display;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	vnc_display_set_scaling (_tmp8_, TRUE);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp9_ = (GtkWindow*) gtk_window_new (GTK_WINDOW_TOPLEVEL);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_object_ref_sink (_tmp9_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_object_unref0 (self->priv->window);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->window = _tmp9_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp10_ = self->priv->window;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp11_ = self->priv->display;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	gtk_container_add ((GtkContainer*) _tmp10_, (GtkWidget*) _tmp11_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp12_ = self->priv->display;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	gtk_widget_realize ((GtkWidget*) _tmp12_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp13_ = self->priv->display;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_connect_object (_tmp13_, "vnc-initialized", (GCallback) __boxes_vnc_display___lambda78__vnc_display_vnc_initialized, self, 0);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp14_ = self->priv->display;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_connect_object (_tmp14_, "vnc-disconnected", (GCallback) __boxes_vnc_display___lambda79__vnc_display_vnc_disconnected, self, 0);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp15_ = self->priv->display;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_connect_object (_tmp15_, "vnc-auth-failure", (GCallback) __boxes_vnc_display___lambda80__vnc_display_vnc_auth_failure, self, 0);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp16_ = self->priv->display;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_connect_object (_tmp16_, "vnc-auth-unsupported", (GCallback) __boxes_vnc_display___lambda81__vnc_display_vnc_auth_unsupported, self, 0);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_tmp17_ = self->priv->display;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_signal_connect_object (_tmp17_, "vnc-auth-credential", (GCallback) __boxes_vnc_display___lambda82__vnc_display_vnc_auth_credential, self, 0);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	return obj;
#line 1063 "vnc-display.c"
}


static void boxes_vnc_display_class_init (BoxesVncDisplayClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	boxes_vnc_display_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesVncDisplayPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->get_display = boxes_vnc_display_real_get_display;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->set_enable_audio = boxes_vnc_display_real_set_enable_audio;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->get_pixbuf = boxes_vnc_display_real_get_pixbuf;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->connect_it = boxes_vnc_display_real_connect_it;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->disconnect_it = boxes_vnc_display_real_disconnect_it;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->get_properties = boxes_vnc_display_real_get_properties;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	((BoxesDisplayClass *) klass)->send_keys = boxes_vnc_display_real_send_keys;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_protocol = boxes_vnc_display_real_get_protocol;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_uri = boxes_vnc_display_real_get_uri;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_vnc_display_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_vnc_display_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_vnc_display_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_VNC_DISPLAY_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_VNC_DISPLAY_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1100 "vnc-display.c"
}


static void boxes_vnc_display_instance_init (BoxesVncDisplay * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv = BOXES_VNC_DISPLAY_GET_PRIVATE (self);
#line 1107 "vnc-display.c"
}


static void boxes_vnc_display_finalize (GObject* obj) {
	BoxesVncDisplay * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_object_unref0 (self->priv->display);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_free0 (self->priv->host);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	_g_object_unref0 (self->priv->window);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	self->priv->saved_properties = (_vala_BoxesBoxConfigSavedProperty_array_free (self->priv->saved_properties, self->priv->saved_properties_length1), NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	G_OBJECT_CLASS (boxes_vnc_display_parent_class)->finalize (obj);
#line 1125 "vnc-display.c"
}


GType boxes_vnc_display_get_type (void) {
	static volatile gsize boxes_vnc_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_vnc_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesVncDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_vnc_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesVncDisplay), 0, (GInstanceInitFunc) boxes_vnc_display_instance_init, NULL };
		GType boxes_vnc_display_type_id;
		boxes_vnc_display_type_id = g_type_register_static (BOXES_TYPE_DISPLAY, "BoxesVncDisplay", &g_define_type_info, 0);
		g_once_init_leave (&boxes_vnc_display_type_id__volatile, boxes_vnc_display_type_id);
	}
	return boxes_vnc_display_type_id__volatile;
}


static void _vala_boxes_vnc_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesVncDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		case BOXES_VNC_DISPLAY_PROTOCOL:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		g_value_set_string (value, boxes_display_get_protocol ((BoxesDisplay*) self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		case BOXES_VNC_DISPLAY_URI:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		g_value_take_string (value, boxes_display_get_uri ((BoxesDisplay*) self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		break;
#line 1158 "vnc-display.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/vnc-display.vala"
		break;
#line 1164 "vnc-display.c"
	}
}



